'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactMultiLang = require('react-multi-lang');

var _AppBar = require('@material-ui/core/AppBar');

var _AppBar2 = _interopRequireDefault(_AppBar);

var _Toolbar = require('@material-ui/core/Toolbar');

var _Toolbar2 = _interopRequireDefault(_Toolbar);

var _styles = require('@material-ui/core/styles');

var _Typography = require('@material-ui/core/Typography');

var _Typography2 = _interopRequireDefault(_Typography);

var _Brightness = require('@material-ui/icons/Brightness1');

var _Brightness2 = _interopRequireDefault(_Brightness);

var _defaultColors = require('../js/defaultColors');

var _defaultColors2 = _interopRequireDefault(_defaultColors);

var _en = require('../translation/en.js');

var _en2 = _interopRequireDefault(_en);

var _fr = require('../translation/fr.js');

var _fr2 = _interopRequireDefault(_fr);

var _WalletDialog = require('./WalletDialog');

var _WalletDialog2 = _interopRequireDefault(_WalletDialog);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _reactMultiLang.setTranslations)({ en: _en2.default, fr: _fr2.default });
(0, _reactMultiLang.setDefaultLanguage)('en');

const supportedLanguages = ['en', 'fr'];
const defaultLanguage = supportedLanguages[0];
const defaultAddr = "0xd00551b9d6CB3C4dDfc36df874c642b19D2b9e22";

let language = navigator !== undefined ? navigator.language || navigator.userLanguage : 'en';
language = language.substr(0, 2);

const getLanguage = () => {
  if (language !== undefined && language.length) {
    const lowerCaseLanguage = language.toLowerCase();
    if (supportedLanguages.includes(lowerCaseLanguage)) {
      return lowerCaseLanguage;
    }
  }
  return defaultLanguage;
};

const findGetParameter = parameterName => {
  var result = null,
      tmp = [];
  var items = location.search.substr(1).split("&");
  for (var index = 0; index < items.length; index++) {
    tmp = items[index].split("=");
    if (tmp[0] === parameterName) result = decodeURIComponent(tmp[1]);
  }
  return result;
};

(0, _reactMultiLang.setDefaultLanguage)(getLanguage());

class DappBar extends _react2.default.Component {
  constructor(props) {
    super(props);
    this.state = { addressChanged: false, accountError: undefined };
    sessionStorage.setItem("BTU-walletConnected", false);
  }

  componentDidMount() {
    const jquery = document.createElement("script");
    const web3js = document.createElement("script");
    const { restrictDomain } = this.props;

    jquery.src = "https://cdnjs.cloudflare.com/ajax/libs/jquery/3.3.1/jquery.min.js";
    jquery.async = true;

    web3js.src = "https://cdn.jsdelivr.net/gh/ethereum/web3.js@1.0.0-beta.34/dist/web3.min.js";
    web3js.async = true;

    document.body.appendChild(jquery);
    document.body.appendChild(web3js);

    const onAccountGet = (err, res) => {
      if (err) {
        this.setState({ accountError: err });
      } else {
        this.onInputWallet(res[0]);
      }
    };

    if (restrictDomain === undefined || typeof restrictDomain == "string" && restrictDomain === window.location.hostname || Array.isArray(restrictDomain) && restrictDomain.includes(window.location.hostname)) {
      window.addEventListener('load', async () => {
        if (window.ethereum) {
          window.web3 = new Web3(ethereum);
          try {
            await ethereum.enable();
            window.web3.eth.getAccounts(onAccountGet);
          } catch (error) {
            this.setState({ accountError: error });
          }
        } else if (window.web3) {
          window.web3 = new Web3(web3.currentProvider);
          window.web3.eth.getAccounts(onAccountGet);
        } else {
          console.log(this.props.t('dappBar.nonEtherumBrowser'));
        }
      });
    }
  }

  onInputWallet(addresse) {
    if (addresse) {
      sessionStorage.setItem('BTU-walletAddr', addresse);
      sessionStorage.setItem("BTU-walletConnected", true);
      this.setState({ addressChanged: true });
    }
  }

  render() {
    const { classes, t, restrictDomain } = this.props;
    const { addressChanged } = this.state;
    const addresseBTU = sessionStorage.getItem('BTU-walletAddr');
    const isConnected = Boolean(addresseBTU) && addressChanged !== defaultAddr || addressChanged;
    const languageParam = findGetParameter("hl");
    const transformWallet = addresseBTU ? addresseBTU.substring(0, 5) + '...' + addresseBTU.substring(38, 42) : '';

    if (languageParam !== null && supportedLanguages.includes(languageParam.toLowerCase())) {
      (0, _reactMultiLang.setDefaultLanguage)(languageParam.toLowerCase());
    }

    if (restrictDomain !== undefined && (typeof restrictDomain == "string" && restrictDomain !== window.location.hostname || Array.isArray(restrictDomain) && !restrictDomain.includes(window.location.hostname))) {
      const walletAddr = findGetParameter("w");
      const pattern = new RegExp('^0[xX][0-9A-Fa-f]{40}$');
      if (walletAddr !== null && pattern.test(walletAddr) && addresseBTU !== walletAddr) this.onInputWallet(walletAddr);else if (walletAddr === null || !pattern.test(walletAddr)) sessionStorage.setItem('BTU-walletAddr', defaultAddr);
      return null;
    }

    return _react2.default.createElement(
      'div',
      null,
      _react2.default.createElement(
        _AppBar2.default,
        { position: 'static', className: classes.barStyle },
        _react2.default.createElement(
          _Toolbar2.default,
          { className: classes.ToolBar },
          _react2.default.createElement(
            'div',
            { className: classes.leftPanel },
            _react2.default.createElement(
              _Typography2.default,
              { variant: 'caption', color: 'inherit', className: classes.connectionText },
              isConnected ? t('dappBar.connected') : t('dappBar.connectionRequired')
            )
          ),
          _react2.default.createElement(
            'div',
            { className: classes.rightPanel },
            _react2.default.createElement(
              _Typography2.default,
              { variant: 'caption', className: classes.statusText },
              isConnected ? transformWallet : t('dappBar.notConnected')
            ),
            _react2.default.createElement(_Brightness2.default, { className: isConnected ? classes.connected : classes.notConnected }),
            _react2.default.createElement(_WalletDialog2.default, {
              onInputWallet: this.onInputWallet.bind(this),
              isOpen: !isConnected
            })
          )
        )
      )
    );
  }
}

const styles = {
  connectionText: {
    fontFamily: "'Poppins', sans-serif",
    fontWeight: 'bold',
    color: _defaultColors2.default.dappBarTextColor,
    fontSize: 12,
    marginBottom: 0
  },
  metaLogo: {
    width: 20,
    height: 18.62,
    marginRight: 10
  },
  barStyle: {
    height: 22,
    backgroundColor: _defaultColors2.default.dappBarBackgroundColor
  },
  notConnected: {
    color: _defaultColors2.default.errorColor,
    width: 20,
    height: 12
  },
  connected: {
    color: _defaultColors2.default.okColor,
    width: 20,
    height: 12
  },
  statusText: {
    fontSize: 11,
    color: _defaultColors2.default.dappBarTextColor
  },
  ToolBar: {
    minHeight: 'unset',
    height: '100%',
    justifyContent: 'space-between'
  },
  leftPanel: {
    display: 'flex',
    alignItems: 'center'
  },
  rightPanel: {
    display: 'flex',
    alignItems: 'center'
  }
};

exports.default = (0, _styles.withStyles)(styles)((0, _reactMultiLang.translate)(DappBar));