'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _styles = require('@material-ui/core/styles');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _FormControl = require('@material-ui/core/FormControl');

var _FormControl2 = _interopRequireDefault(_FormControl);

var _FormLabel = require('@material-ui/core/FormLabel');

var _FormLabel2 = _interopRequireDefault(_FormLabel);

var _Input = require('@material-ui/core/Input');

var _Input2 = _interopRequireDefault(_Input);

var _defaultColors = require('../js/defaultColors');

var _defaultColors2 = _interopRequireDefault(_defaultColors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const navigateur = 'User-agent header sent: ' + navigator.userAgent;
const flag = navigateur.indexOf('Firefox') > -1 ? 1 : 0;

const styles = {
  formControl: {
    width: '100%'
  },
  textField: {
    border: '0.5px solid ' + _defaultColors2.default.defaultTextColor,
    height: 45,
    borderRadius: 25,
    paddingLeft: 20,
    paddingRight: 20,
    marginTop: '5px !important'
  },
  textFieldError: {
    border: '1.5px solid ' + _defaultColors2.default.errorColor
  },
  error: {
    color: _defaultColors2.default.errorColor,
    fontSize: '0.9em',
    fontWeight: 'bold',
    fontFamily: '"Poppins", sans-serif',
    marginTop: 6
  }
};

class BtuTextField extends _react.Component {
  constructor(props) {
    super(props);
    this.state = {
      stateInputId: '',
      stateValue: ''
    };
  }

  componentDidMount() {
    this.setState({ stateInputId: 'btu-input-' + Math.round(Math.random() * 1000000) });
  }

  componentWillReceiveProps(props) {
    if (props.value !== undefined) {
      const newState = this.state;
      newState.stateValue = props.value;
      this.setState(newState);
    }
  }

  handleChange(newVal, inputType) {
    const { onChange } = this.props;
    let checkedVal = newVal;
    if (inputType === 'number' || inputType === 'tel') {
      checkedVal = newVal.replace(/\D/g, '');
    }
    this.setState({ stateValue: checkedVal });
    onChange({
      value: checkedVal,
      isValid: this.validateValue(checkedVal)
    });
  }

  validateValue(value) {
    const { required, validate } = this.props;
    if (required && value === '') {
      return false;
    }
    return validate(value);
  }

  addZero(nbChiffres, value) {
    const logValue = Math.round(Math.log10(value));
    let str = value.toString();
    for (let i = 0; i < nbChiffres - logValue; i++) {
      str = '0' + str;
    }
    return str;
  }

  render() {
    const {
      classes,
      inputId,
      title,
      inputType,
      value,
      placeholder,
      disabled,
      required,
      checkValidity,
      validate,
      requiredMessage,
      invalidMessage,
      maxLength
    } = this.props;

    const {
      stateInputId,
      stateValue
    } = this.state;

    return _react2.default.createElement(
      _FormControl2.default,
      { className: classes.formControl },
      _react2.default.createElement(
        _FormLabel2.default,
        { htmlFor: inputId !== null ? inputId : stateInputId, style: { width: flag ? ' -moz-max-content' : 'max-content' } },
        title
      ),
      _react2.default.createElement(_Input2.default, {
        id: inputId !== null ? inputId : stateInputId,
        value: value,
        placeholder: placeholder,
        disabled: disabled,
        onChange: newVal => this.handleChange(newVal.target.value, inputType),
        onInput: e => {
          e.target.value = inputType === 'number' || inputType === 'tel' ? e.target.value.toString().slice(0, maxLength) : e.target.value;
        },
        className: (0, _classnames2.default)({
          [classes.textField]: true,
          [classes.textFieldError]: required && checkValidity && (!stateValue || stateValue === '' || checkValidity && !validate(stateValue))
        }),
        disableUnderline: true,
        type: inputType
      }),
      required && checkValidity && (!stateValue || stateValue === '' ? _react2.default.createElement(
        'div',
        { className: classes.error },
        requiredMessage
      ) : checkValidity && !validate(stateValue) && _react2.default.createElement(
        'div',
        { className: classes.error },
        invalidMessage
      ))
    );
  }
}

exports.default = (0, _styles.withStyles)(styles)(BtuTextField);